@@ -1,7 +1,7 @@
 # coding: utf-8
 
-# Copyright © 2011-2012 Julian Mehnle <julian@mehnle.net>,
-# Copyright © 2011-2012 Scott Kitterman <scott@kitterman.com>
+# Copyright © 2011-2013 Julian Mehnle <julian@mehnle.net>,
+# Copyright © 2011-2013 Scott Kitterman <scott@kitterman.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -93,7 +93,7 @@ MODULE = 'authres'
 
 __author__  = 'Julian Mehnle, Scott Kitterman'
 __email__   = 'julian@mehnle.net'
-__version__ = '0.401'
+__version__ = '0.500'
 
 import authres.core
 
@@ -224,13 +224,4 @@ def parse(string):
 def parse_value(string):
     return core_features().parse_value(string)
 
-
-def _test():
-    import doctest
-    import authres
-    doctest.testfile("tests")
-    return doctest.testmod(authres)
-
-_test()
-
 # vim:sw=4 sts=4
