@@ -1,7 +1,7 @@
 # coding: utf-8
 
-# Copyright © 2012 Julian Mehnle <julian@mehnle.net>,
-# Copyright © 2012 Scott Kitterman <scott@kitterman.com>
+# Copyright © 2012-2013 Julian Mehnle <julian@mehnle.net>,
+# Copyright © 2012-2013 Scott Kitterman <scott@kitterman.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@ authres extension module for RFC 6008 DKIM signature identification (header.b).
 
 __author__  = 'Scott Kitterman, Julian Mehnle'
 __email__   = 'scott@kitterman.com'
-__version__ = '0.402'
+__version__ = '0.500'
 
 import authres.core
 from authres.core import make_result_class_properties
@@ -54,6 +54,24 @@ class DKIMAuthenticationResult(authres.core.AuthenticationResult):
     header_i,             header_i_comment             = make_result_class_properties('header', 'i')
     header_b,             header_b_comment             = make_result_class_properties('header', 'b')
 
+    def match_signature(self, signature_d, signature_b = None, strict = False):
+        """Match authentication result against a DKIM signature by ``header.d``
+        and, if available, ``header.b``, per RFC 6008, section 4
+        <http://tools.ietf.org/html/rfc6008#section-4>.  If ``header.b`` is
+        absent from the authentication result, a non-strict match succeeds,
+        whereas a strict match fails."""
+
+        if self.header_d != signature_d:
+            return False
+        if self.header_b is None:
+            return not strict
+        if len(self.header_b) >= 8:
+            # Require prefix match:
+            return signature_b.startswith(self.header_b)
+        else:
+            # Require exact match:
+            return self.header_b == signature_b
+
 RESULT_CLASSES = [
     DKIMAuthenticationResult
 ]
